==============
Code reference
==============

.. toctree::
  :maxdepth: 2


analyze (Generic fitting wrapper)
=================================
.. autofunction:: qpsphere.analyze


edgefit (Contour-based fitting)
===============================
.. automodule:: qpsphere.edgefit
   :members:
   :undoc-members:


imagefit (2D phase image fitting)
=================================
.. automodule:: qpsphere.imagefit
   :members:
   :undoc-members:

imagefit.alg (Algorithms)
-------------------------
.. automodule:: qpsphere.imagefit.alg
   :members:
   :undoc-members:

imagefit.interp (Image interpolation logic)
-------------------------------------------
.. automodule:: qpsphere.imagefit.interp
   :members:
   :undoc-members:


models (Scattering models)
==========================
.. automodule:: qpsphere.models
   :members:
   :undoc-members:


util (Helper methods)
==========================
.. automodule:: qpsphere.util
   :members:
   :undoc-members:
